package com.chenyang.nse.bussiness.service.console;

import com.chenyang.nse.bussiness.entity.orm.table.base.TBaseMenu;
import com.chenyang.nse.bussiness.entity.vo.MenuRtVO;
import com.chenyang.nse.bussiness.entity.vo.TreeVO;
import java.util.List;

public interface MenuService {
   List<TBaseMenu> queryMenuByParentId(String parentid, String flag);

   List<TBaseMenu> queryMenuByParentId1(String parentid, String flag);

   void remove(List<String> idlist);

   void remove(String note);

   void add(TBaseMenu menu);

   boolean isMenunameExist(String menuname);

   void modifyMenu(TBaseMenu menu, String username);

   void sortMenu(List<String> idlist);

   List<TreeVO> queryMenuTree(String flag);

   List<TreeVO> getMenuTreeList(String type);

   int add(TBaseMenu menu, List<TBaseMenu> subMenu, String username);

   int add(TBaseMenu menu, List<TBaseMenu> subMenu);

   int add(String menuId, String note, List<TBaseMenu> subMenu);

   void removerow(String id);

   TBaseMenu queryMenueByid(String id);

   List<MenuRtVO> queryMenuAll();
}
